weaviate.gql
============

.. automodule:: weaviate.gql
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.gql.aggregate
----------------------

.. automodule:: weaviate.gql.aggregate
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.gql.filter
-------------------

.. automodule:: weaviate.gql.filter
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.gql.get
----------------

.. automodule:: weaviate.gql.get
   :members:
   :undoc-members:
   :show-inheritance:
